@@ -66,7 +66,7 @@ def await_function_deployment(client: ExperimentalClient, function_name: str, ma
 
 def experimental_client(project: Project, api_key: str = "", base_url: str = None) -> ExperimentalClient:
     return ExperimentalClient(
-        api_key=api_key if api_key else PROJECT_TO_API_KEYS[project].get_deployment_key(),
+        api_key=api_key if api_key else PROJECT_TO_API_KEYS[project].get_client_api_key(),
         client_name="AIR Functions Client",
         project=project.value,
         base_url=base_url if base_url else PROJECT_TO_API_KEYS[project].base_url,
