@@ -1,13 +1,10 @@
-import os
 from pathlib import Path
-from typing import Dict, Iterator, Optional, Union
+from typing import Dict, Iterator, Union
 
 from cognite.client.exceptions import CogniteAPIError
 from cognite.experimental import CogniteClient
 from cognite.experimental.data_classes import Function
 from requests.exceptions import ConnectionError
-from slack import WebClient
-from slack.errors import SlackApiError
 from urllib3.exceptions import MaxRetryError, ReadTimeoutError
 
 from cognite.airworkflow.util import cdf, env
@@ -49,7 +46,6 @@ def deploy_function(
     secrets = format_secret_names(secrets)
     print("Deploying function ...", flush=True)
     x = 0
-    thread = None
     while x < 3:
         try:
             function = client.functions.create(
@@ -79,14 +75,6 @@ def deploy_function(
                 delete_function_if_exists(client, function_name)
             else:
                 x += 1
-            response = post_to_slack(
-                WebClient(os.environ["SLACK_TOKEN"]),
-                channel=CHANNEL,
-                message_text=repr(e),
-                thread=thread,
-            )
-            if response:
-                thread = response.data["ts"]
             if x >= 3:
                 raise TimeoutError("Tried to deploy three times and failed.")
 
@@ -131,31 +119,3 @@ def get_function_name(
 
 def get_relative_function_path(path: Path) -> str:
     return "/".join(path.parts[path.parts.index("functions") + 1 :])  # noqa
-
-
-def post_to_slack(
-    slack_client: WebClient,
-    channel: str,
-    message_text: str,
-    thread: Optional[str] = None,
-):
-    x = 0
-    while x < 3:
-        try:
-            if thread is None:
-                response = slack_client.chat_postMessage(channel=channel, text=message_text)
-            else:
-                response = slack_client.chat_postMessage(channel=channel, text=message_text, thread_ts=thread)
-            assert response.get("message").get("text") == message_text
-            return response
-        except (SlackApiError, AssertionError) as e:
-            x += 1
-            if isinstance(e, SlackApiError):
-                print(SlackApiError)
-                print(e.response["error"])
-                # You will get a SlackApiError if "ok" is False
-                assert e.response["ok"] is False
-                assert e.response["error"]  # str like 'invalid_auth', 'channel_not_found'
-                print(f"Got an error: {e.response['error']}")
-            if x == 3:
-                raise e
